<?php

/**
 * @file
 * sticky_preview.common.inc file
 */

/**
 * Get info about enabled in preview fields.
 *
 * @param array $fields
 *   Array with enabled fields from settings.
 *
 * @param $node_type
 *   Node type.
 *
 * @return array
 *   Array with fields information keyed by fields names.
 */
function sticky_preview_get_fields_info(array $fields, $node_type) {
  $result = array();
  $fields_info = sticky_preview_field_info_instances('node', $node_type);

  foreach ($fields as $key => $field_name) {
    $result[$field_name] = $fields_info[$field_name];
    $result[$field_name]['field_item_id'] = str_replace('_', '-', $field_name) . '-sticky-preview-item';
    $result[$field_name]['field_placeholder_id'] = str_replace('_', '-', $field_name) . '-sticky-preview-placeholder';
  }

  return $result;
}

/**
 * Extends array generated by field_info_instances() with title 'field'.
 *
 * @param string $entity_type
 *   Entity type.
 *
 * @param $bundle
 *   Bundle.
 *
 * @return array
 *   Extended array with field information.
 */
function sticky_preview_field_info_instances($entity_type, $bundle) {
  $result['title'] = array(
    'label' => t('Title'),
    'field_name' => 'title',
    'required' => TRUE,
  );

  return $result + field_info_instances($entity_type, $bundle);
}

/**
 * Returns human name of content type by machine name.
 *
 * @param string $machine_name
 *   Machine name of content type.
 *
 * @return string
 *   Human content type name.
 */
function sticky_preview_get_content_type_human_name($machine_name) {
  $content_types = node_type_get_types();

  return $content_types[$machine_name]->name;
}

/**
 * Sort fields in settings depends on $form fields weight.
 *
 * @param array $fields
 *   Fields that needs to be sorted.
 *
 * @param array $form
 *   Render array of node form.
 *
 * @return array
 *   Sorted by #weight from node form fields.
 */
function sticky_preview_sort_fields(array $fields, array $form) {
  foreach ($fields as $field_name => &$field_info) {
    $field_info['#weight'] = $form[$field_name]['#weight'];
  }

  usort($fields, 'sticky_preview_weight_sort');

  return $fields;
}

/**
 * Callback for usort() function.
 */
function sticky_preview_weight_sort($first_field, $second_field) {
  return ($first_field['#weight'] < $second_field['#weight']) ? -1 : 1;
}
